aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/gpu/drm/exynos/exynos_drm_gem.h
diff options
context:
space:
mode:
authorJoonyoung Shim <jy0922.shim@samsung.com>2011-12-13 14:39:13 +0900
committerInki Dae <inki.dae@samsung.com>2011-12-29 11:21:41 +0900
commit2364839a1aca677842b0dfd7ed0449acda3c3175 (patch)
treeee5dba46a9859409ea5c939d362883f7873b4255 /drivers/gpu/drm/exynos/exynos_drm_gem.h
parentdrm/exynos: Fix a fake mmap offset creation (diff)
downloadlinux-dev-2364839a1aca677842b0dfd7ed0449acda3c3175.tar.xz
linux-dev-2364839a1aca677842b0dfd7ed0449acda3c3175.zip
drm/exynos: Split creation of gem object and gem handle
exynos_drm_gem_create function created gem object with gem handle but it can be called externally without gem handle creation through this patch. Signed-off-by: Joonyoung Shim <jy0922.shim@samsung.com> Signed-off-by: Inki Dae <inki.dae@samsung.com> Signed-off-by: Kyungmin Park <kyungmin.park@samsung.com>
Diffstat (limited to 'drivers/gpu/drm/exynos/exynos_drm_gem.h')
-rw-r--r--drivers/gpu/drm/exynos/exynos_drm_gem.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/drivers/gpu/drm/exynos/exynos_drm_gem.h b/drivers/gpu/drm/exynos/exynos_drm_gem.h
index 4fe4a8b14818..67cdc9168708 100644
--- a/drivers/gpu/drm/exynos/exynos_drm_gem.h
+++ b/drivers/gpu/drm/exynos/exynos_drm_gem.h
@@ -64,10 +64,11 @@ struct exynos_drm_gem_obj {
struct exynos_drm_gem_buf *buffer;
};
-/* create a new buffer and get a new gem handle. */
+/* destroy a buffer with gem object */
+void exynos_drm_gem_destroy(struct exynos_drm_gem_obj *exynos_gem_obj);
+
+/* create a new buffer with gem object */
struct exynos_drm_gem_obj *exynos_drm_gem_create(struct drm_device *dev,
- struct drm_file *file_priv,
- unsigned int *handle,
unsigned long size);
/*